]> de.git.xonotic.org Git - xonotic/darkplaces.git/commitdiff
remove PRECACHE_PIC_NOCLAMP because it currently has no chance to work
authordivverent <divverent@d7cf8633-e32d-0410-b094-e92efae38249>
Tue, 24 Jan 2012 21:47:10 +0000 (21:47 +0000)
committerdivverent <divverent@d7cf8633-e32d-0410-b094-e92efae38249>
Tue, 24 Jan 2012 21:47:10 +0000 (21:47 +0000)
git-svn-id: svn://svn.icculus.org/twilight/trunk/darkplaces@11658 d7cf8633-e32d-0410-b094-e92efae38249

dpdefs/csprogsdefs.qc
dpdefs/menudefs.qc
gl_draw.c
prvm_cmds.c

index d3348bc50930a311790987ebd3291733c0bb1438..2d376d4fe41cf0f16832856850e3239cda1b72f5 100644 (file)
@@ -1083,7 +1083,6 @@ float MOVETYPE_FLY_WORLDONLY = 33;
 //constant definitions:
 float PRECACHE_PIC_FROMWAD = 1; // this one actually is part of EXT_CSQC
 float PRECACHE_PIC_NOTPERSISTENT = 2; // picture may get deallocated when unused
-float PRECACHE_PIC_NOCLAMP = 4; // do not clamp to edge
 float PRECACHE_PIC_MIPMAP = 8; // mipmap the texture for possibly better downscaling at memory expense
 //notes: these constants are given as optional second argument to precache_pic()
 
index bf22931940562b04d47685c940b405142f8ca1b4..ad8666ed3548786759d2faeb6b9c59dcd5711377 100644 (file)
@@ -410,7 +410,6 @@ float(string s1, string s2, float len) strncasecmp = #230;
 //constant definitions:
 float PRECACHE_PIC_FROMWAD = 1; // this one actually is part of EXT_CSQC
 float PRECACHE_PIC_NOTPERSISTENT = 2; // picture may get deallocated when unused
-float PRECACHE_PIC_NOCLAMP = 4; // do not clamp to edge
 float PRECACHE_PIC_MIPMAP = 8; // mipmap the texture for possibly better downscaling at memory expense
 //notes: these constants are given as optional second argument to precache_pic()
 
index 127a0b377c8c30fc299255750095d971a8c78cae..589140e26fc57305a3f5b2749aec2f95b9bb42d5 100644 (file)
--- a/gl_draw.c
+++ b/gl_draw.c
@@ -343,7 +343,7 @@ cachepic_t *Draw_CachePic_Flags(const char *path, unsigned int cachepicflags)
                        // if it was created (or replaced) by Draw_NewPic, just return it
                        if(pic->flags & CACHEPICFLAG_NEWPIC)
                                return pic;
-                       if (!((pic->texflags ^ texflags) & ~(TEXF_COMPRESS))) // ignore TEXF_COMPRESS when comparing, because fallback pics remove the flag
+                       if (!((pic->texflags ^ texflags) & ~(TEXF_COMPRESS | TEXF_MIPMAP))) // ignore TEXF_COMPRESS when comparing, because fallback pics remove the flag, and ignore TEXF_MIPMAP because QC specifies that
                        {
                                if(!(cachepicflags & CACHEPICFLAG_NOTPERSISTENT))
                                {
index 4e9cd325edc68841b1ddd61c42e7ba05e105122b..fab17c9b26bb5bab877ee0359f9696fa4abdbdec 100644 (file)
@@ -3243,7 +3243,7 @@ string    precache_pic(string pic)
 */
 #define PRECACHE_PIC_FROMWAD 1 /* FTEQW, not supported here */
 #define PRECACHE_PIC_NOTPERSISTENT 2
-#define PRECACHE_PIC_NOCLAMP 4
+//#define PRECACHE_PIC_NOCLAMP 4
 #define PRECACHE_PIC_MIPMAP 8
 void VM_precache_pic(prvm_prog_t *prog)
 {
@@ -3261,8 +3261,8 @@ void VM_precache_pic(prvm_prog_t *prog)
                int f = PRVM_G_FLOAT(OFS_PARM1);
                if(f & PRECACHE_PIC_NOTPERSISTENT)
                        flags |= CACHEPICFLAG_NOTPERSISTENT;
-               if(f & PRECACHE_PIC_NOCLAMP)
-                       flags |= CACHEPICFLAG_NOCLAMP;
+               //if(f & PRECACHE_PIC_NOCLAMP)
+               //      flags |= CACHEPICFLAG_NOCLAMP;
                if(f & PRECACHE_PIC_MIPMAP)
                        flags |= CACHEPICFLAG_MIPMAP;
        }